@@ -305,3 +305,43 @@ pt.sample <- function() {
 
     return(pt)
 }
+
+#' it.sample
+#'
+#' Returns sample IntensityTier.
+#'
+#' @return IntensityTier
+#' @export
+#' @seealso \code{\link{it.plot}}
+#'
+#' @examples
+#' it <- it.sample()
+#' it.plot(it)
+it.sample <- function() {
+    it <- structure(list(t = c(0.0501814058956916, 0.061609977324263, 0.0730385487528345,
+    0.0844671201814059, 0.0958956916099773, 0.107324263038549, 0.11875283446712,
+    0.130181405895692, 0.141609977324263, 0.153038548752834, 0.164467120181406,
+    0.175895691609977, 0.187324263038549, 0.19875283446712, 0.210181405895692,
+    0.221609977324263, 0.233038548752834, 0.244467120181406, 0.255895691609977,
+    0.267324263038549, 0.27875283446712, 0.290181405895692, 0.301609977324263,
+    0.313038548752834, 0.324467120181406, 0.335895691609977, 0.347324263038549,
+    0.35875283446712, 0.370181405895692, 0.381609977324263, 0.393038548752834,
+    0.404467120181406, 0.415895691609977, 0.427324263038549, 0.43875283446712,
+    0.450181405895692, 0.461609977324263, 0.473038548752834, 0.484467120181406,
+    0.495895691609977),
+    i = c(59.5715903919772, 64.2433970281169,
+    66.7307025767877, 68.6118601972034, 69.64503935886, 69.9890705893054,
+    70.0931250569067, 69.9080233229584, 69.5408798931165, 68.6145599393597,
+    67.7338052604723, 68.8843393012335, 70.4440821351615, 71.3240051264438,
+    71.6253943894252, 71.6384332518872, 71.6143276399569, 71.1700597706145,
+    70.095823123869, 68.8978679914131, 68.6011647679974, 69.5956454731659,
+    70.8841436215361, 71.627781998734, 71.8105755630646, 71.397700225839,
+    70.1676187462884, 67.8707663965455, 64.1717622005677, 59.2915859514638,
+    56.5792583100872, 58.2129564806205, 58.4726837633976, 58.43640324365,
+    64.9729454833362, 69.3800338825861, 70.8984471257152, 70.2640179212008,
+    68.0519528346286, 64.9896327040883), tmin = 0, tmax = 0.546077097505669), .Names = c("t", "i", "tmin", "tmax"))
+
+    return(it)
+}
+
+
